#
# spec file for package python-github3.py
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-github3.py
Version:        4.0.1
Release:        1.7
Summary:        Python wrapper for the GitHub API
License:        BSD-3-Clause
URL:            https://github.com/sigmavirus24/github3.py
Source0:        https://files.pythonhosted.org/packages/source/g/github3.py/github3.py-%{version}.tar.gz
Source20:       https://raw.githubusercontent.com/sigmavirus24/github3.py/%{version}/tests/id_rsa.pub
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyJWT >= 2.3.0
Requires:       python-jwcrypto >= 0.5.0
Requires:       python-python-dateutil >= 2.6.0
Requires:       python-requests >= 2.18
Requires:       python-uritemplate >= 3.0.0
Recommends:     python-ndg-httpsclient
Recommends:     python-pyOpenSSL
Recommends:     python-pyasn1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module betamax >= 0.8.0}
BuildRequires:  %{python_module PyJWT >= 2.3.0}
BuildRequires:  %{python_module betamax-matchers >= 0.1.0}
BuildRequires:  %{python_module jwcrypto >= 0.5.0}
BuildRequires:  %{python_module pytest > 2.3.5}
BuildRequires:  %{python_module python-dateutil >= 2.6.0}
BuildRequires:  %{python_module requests >= 2.18}
BuildRequires:  %{python_module uritemplate >= 3.0.0}
# /SECTION
%python_subpackages

%description
Github3.py is wrapper for v3 of the GitHub API written in python.

%prep
%setup -q -n github3.py-%{version}
cp %{SOURCE20} tests/

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -c /dev/null -k 'not (test_patch or test_diff)'

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%{python_sitelib}/github3
%{python_sitelib}/github3.py-%{version}.dist-info

%changelog
* Wed Jun 28 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.0.1:
  * github3.repos.comparison.Comparison.commits was renamed to
    original_commits.
  * Add tests for Python 3.11
  * Add function for getting repos for github app
  * Cancel and failed invitation
  * Allow to set GitHub API version
  * Remove support to EOL Python 3.6
  * Missing set permission for collaborators
  * Modernize the build: switch to hatchling
- Stop using greedy globs in %%files.
* Fri May  6 2022 pgajdos@suse.com
- version update to 3.2.0
  https://github3.readthedocs.io/en/latest/release-notes/3.2.0.html
- python-mock is not required for build
* Wed Feb 16 2022 pgajdos@suse.com
- update to 3.1.0:
  https://github3.readthedocs.io/en/latest/release-notes/3.1.0.html
  https://github3.readthedocs.io/en/latest/release-notes/3.0.0.html
  https://github3.readthedocs.io/en/latest/release-notes/2.0.0.html
* Thu Mar 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.0:
  * Add partial support for the Checks API:
  * Add unignore method to unignore notifications from repository for the user, to Repository and ShortRepository classes.
  * Add unsubscribe method to unsubscribe the user to repository's notifications, to Repository and ShortRepository classes.
  * Add support for webhooks in an organization
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Mar  5 2018 toddrme2178@gmail.com
- Initial version
